{% extends "wiki/__base.html" %}

{% load wiki_extras %}

{% block title %}Wiki Home{% endblock %}

{% block mainheading %}
My Wiki
{% endblock %}

{% block content %}

<p>Greetings <b>{{ user.first_name }}</b>. This will be your page with all your stuff on it. Such as:</p>

<ul>
    <li>Recently edited</li>
    <li>Faved Pages/Spaces etc.</li>
    <li>Account details/functionality</li>
    <li>...</li>
</ul>

{% endblock %}


{% block footer %}
<a href="/">Site Home</a>
{% endblock %}
