# Generated by Django 5.0.6 on 2024-06-26 11:12

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wikiwikiweb', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalwikispace',
            name='homepage',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='wikiwikiweb.wikipage'),
        ),
        migrations.AddField(
            model_name='wikispace',
            name='homepage',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='wikiwikiweb.wikipage'),
        ),
    ]
